@@ -4,7 +4,7 @@ from threading import Lock
 from bson import ObjectId
 
 from licsber.mongo import random_get, idd_split_path
-from licsber.s3 import S3Sign
+from .pre_sign import S3Sign
 
 
 class LinkGen:
@@ -19,9 +19,7 @@ class LinkGen:
         self.sign = S3Sign(endpoint, access_key, secret_key)
 
     def _request_db(self):
-        return random_get(self.db, match={
-            'save': True,
-        }, size=self.pre_fetch, project={'suffix': True})
+        return random_get(self.db, match={}, size=self.pre_fetch, project={'suffix': True})
 
     def _gen_link(self, idd, suffix):
         path = idd_split_path(idd, suffix)
