@@ -1,3 +1,5 @@
+import functools
+import random
 import time
 
 
@@ -19,6 +21,15 @@ def get_timestamp() -> int:
     return int(now_time)
 
 
+def get_timestamp_mil() -> int:
+    """
+    获取1970年到现在UTC的毫秒数.
+    :return: 自1970年1月1日 0点0分0秒以来的秒数.
+    """
+    now_time = time.time() * 1000 + random.randint(0, 999)
+    return int(now_time)
+
+
 def get_timestamp_str() -> str:
     """
     获取当前本地时间, 格式为[2020-12-12 11:22:33].
@@ -37,15 +48,16 @@ def cal_time(output=False, fps=False):
     """
 
     def decorator(fun):
+        @functools.wraps(fun)
         def wrapper(*args, **kwargs):
             last = time.time()
             res = fun(*args, **kwargs)
             real_time = time.time() - last
             if output:
                 if fps:
-                    print(f"FPS: {1 / real_time:.2f}")
+                    print(f"FPS: {1 / real_time:.3f}")
                 else:
-                    print(f"执行时间: {real_time:.2f}s")
+                    print(f"执行时间: {real_time:.3f}s")
             if not res:
                 return None
             return real_time, res
